This directory contains third-party license information for projects that LTD Keeper is derived from.
See individual source files for specific attribution.

See ../LICENSE for LTD Keeper's main license information.
